@@ -185,10 +185,24 @@ void ValueFederate::registerInterfaces(const std::string& configString)
 
 void ValueFederate::registerValueInterfaces(const std::string& configString)
 {
-    if (fileops::hasTomlExtension(configString)) {
-        registerValueInterfacesToml(configString);
-    } else {
-        registerValueInterfacesJson(configString);
+    auto hint = fileops::getConfigType(configString);
+    switch (hint) {
+        case fileops::ConfigType::JSON_FILE:
+        case fileops::ConfigType::JSON_STRING:
+            try {
+                registerValueInterfacesJson(configString);
+            }
+            catch (const std::invalid_argument& e) {
+                throw(helics::InvalidParameter(e.what()));
+            }
+            break;
+        case fileops::ConfigType::TOML_FILE:
+        case fileops::ConfigType::TOML_STRING:
+            registerValueInterfacesToml(configString);
+            break;
+        case fileops::ConfigType::NONE:
+        default:
+            break;
     }
 }
 static constexpr std::string_view emptyStr;
