@@ -20,9 +20,8 @@ ValueFederateManager::ValueFederateManager(Core* coreOb,
                                            ValueFederate* vfed,
                                            LocalFederateId id,
                                            bool singleThreaded):
-    fedID(id),
-    inputs(!singleThreaded), publications(!singleThreaded), coreObject(coreOb), fed(vfed),
-    inputData(!singleThreaded), targetIDs(!singleThreaded), inputTargets(!singleThreaded)
+    fedID(id), inputs(!singleThreaded), publications(!singleThreaded), coreObject(coreOb),
+    fed(vfed), inputData(!singleThreaded), targetIDs(!singleThreaded), inputTargets(!singleThreaded)
 {
 }
 ValueFederateManager::~ValueFederateManager() = default;
