@@ -132,8 +132,7 @@ Player::Player(std::string_view appName, const FederateInfo& fedInfo): App(appNa
 
 Player::Player(std::string_view appName,
                const std::shared_ptr<Core>& core,
-               const FederateInfo& fedInfo):
-    App(appName, core, fedInfo)
+               const FederateInfo& fedInfo): App(appName, core, fedInfo)
 {
     initialSetup();
 }
