@@ -110,6 +110,7 @@ std::shared_ptr<helicsCLI11App> BrokerBase::generateBaseCLI()
     auto hApp = std::make_shared<helicsCLI11App>("Arguments applying to all Brokers and Cores");
     auto* fmtr = addJsonConfig(hApp.get());
     fmtr->maxLayers(0);
+    fmtr->promoteSection("helics");
     hApp->option_defaults()->ignore_underscore()->ignore_case();
     hApp->add_option("--federates,-f",
                      minFederateCount,
@@ -236,6 +237,10 @@ std::shared_ptr<helicsCLI11App> BrokerBase::generateBaseCLI()
     hApp->add_flag("--terminate_on_error",
                    terminate_on_error,
                    "specify that a broker should cause the federation to terminate on an error");
+    hApp->add_flag(
+        "--error_on_unmatched",
+        errorOnUnmatchedConnections,
+        "set the broker to terminate the cosimulation if there are unmatched connections");
     mLogManager->addLoggingCLI(hApp);
 
     hApp->add_flag(
